.. peconfigurator documentation master file, created by

Welcome to pe-configurator documentation!
==========================================

PEConfigurator is a tool for performing sanity checks on parameter estimation results and producing recommended parameter estimation settings physically motivated.

Pypi: `https://pypi.org/project/pe-configurator/ <https://pypi.org/project/pe-configurator/>`_

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   source/installation
   source/logic
   source/examples



API
---

.. autosummary::
   :toctree: api
   :template: custom-module-template.rst
   :caption: API:
   :recursive:

   peconfigurator